==> igniteui-angular-charts-17.2.1.tgz: package/esm5/lib/AverageDirectionalIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { AverageDirectionalIndexIndicatorStrategy } from "./AverageDirectionalIndexIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-angular-core";
/**
 * @hidden
 */
var AverageDirectionalIndexIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(AverageDirectionalIndexIndicator, _super);
    function AverageDirectionalIndexIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AverageDirectionalIndexIndicator.prototype.bg = function () {
        return new AverageDirectionalIndexIndicator();
    };
    AverageDirectionalIndexIndicator.prototype.get_yz = function () {
        return new AverageDirectionalIndexIndicatorStrategy();
    };
    Object.defineProperty(AverageDirectionalIndexIndicator.prototype, "yz", {
        get: function () {
            return this.get_yz();
        },
        enumerable: false,
        configurable: true
    });
    AverageDirectionalIndexIndicator.prototype.get_zc = function () {
        return AverageDirectionalIndexIndicator.$;
    };
    Object.defineProperty(AverageDirectionalIndexIndicator.prototype, "zc", {
        get: function () {
            return this.get_zc();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(AverageDirectionalIndexIndicator.prototype, "zk", {
        get: function () {
            return typeGetValue(this.c(AverageDirectionalIndexIndicator.zl));
        },
        set: function (a) {
            this.h(AverageDirectionalIndexIndicator.zl, a);
        },
        enumerable: false,
        configurable: true
    });
    AverageDirectionalIndexIndicator.prototype.y5 = function () {
        return this.zk;
    };
    AverageDirectionalIndexIndicator.prototype.ze = function (a) {
        this.zk = a;
    };
    AverageDirectionalIndexIndicator.$t = markType(AverageDirectionalIndexIndicator, 'AverageDirectionalIndexIndicator', StrategyBasedIndicator.$);
    AverageDirectionalIndexIndicator.zl = StrategyBasedIndicator.zh(14, AverageDirectionalIndexIndicator.$);
    return AverageDirectionalIndexIndicator;
}(StrategyBasedIndicator));
export { AverageDirectionalIndexIndicator };

==> igniteui-angular-charts-17.3.0.tgz: package/esm5/lib/AverageDirectionalIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { AverageDirectionalIndexIndicatorStrategy } from "./AverageDirectionalIndexIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-angular-core";
/**
 * @hidden
 */
var AverageDirectionalIndexIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(AverageDirectionalIndexIndicator, _super);
    function AverageDirectionalIndexIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AverageDirectionalIndexIndicator.prototype.bc = function () {
        return new AverageDirectionalIndexIndicator();
    };
    AverageDirectionalIndexIndicator.prototype.get_y0 = function () {
        return new AverageDirectionalIndexIndicatorStrategy();
    };
    Object.defineProperty(AverageDirectionalIndexIndicator.prototype, "y0", {
        get: function () {
            return this.get_y0();
        },
        enumerable: false,
        configurable: true
    });
    AverageDirectionalIndexIndicator.prototype.get_zd = function () {
        return AverageDirectionalIndexIndicator.$;
    };
    Object.defineProperty(AverageDirectionalIndexIndicator.prototype, "zd", {
        get: function () {
            return this.get_zd();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(AverageDirectionalIndexIndicator.prototype, "zl", {
        get: function () {
            return typeGetValue(this.c(AverageDirectionalIndexIndicator.zm));
        },
        set: function (a) {
            this.h(AverageDirectionalIndexIndicator.zm, a);
        },
        enumerable: false,
        configurable: true
    });
    AverageDirectionalIndexIndicator.prototype.y6 = function () {
        return this.zl;
    };
    AverageDirectionalIndexIndicator.prototype.zf = function (a) {
        this.zl = a;
    };
    AverageDirectionalIndexIndicator.$t = markType(AverageDirectionalIndexIndicator, 'AverageDirectionalIndexIndicator', StrategyBasedIndicator.$);
    AverageDirectionalIndexIndicator.zm = StrategyBasedIndicator.zi(14, AverageDirectionalIndexIndicator.$);
    return AverageDirectionalIndexIndicator;
}(StrategyBasedIndicator));
export { AverageDirectionalIndexIndicator };
